package com.example.db

import eu.maiora.model.LogScript
import kotlinx.coroutines.Dispatchers
import kotlinx.datetime.LocalDateTime
import org.jetbrains.exposed.dao.IntEntity
import org.jetbrains.exposed.dao.IntEntityClass
import org.jetbrains.exposed.dao.id.EntityID
import org.jetbrains.exposed.dao.id.IdTable
import org.jetbrains.exposed.dao.id.IntIdTable
import org.jetbrains.exposed.sql.Table
import org.jetbrains.exposed.sql.Transaction
import org.jetbrains.exposed.sql.javatime.datetime
import org.jetbrains.exposed.sql.transactions.experimental.newSuspendedTransaction

object LogScriptTable : IdTable<Int>("aipoc.log_script") {
    override val id = integer("id").entityId()
    val ts_ricezione = datetime("ts_ricezione")
    val script_ricevuto = varchar("script_ricevuto", 50)
    val script_elaborato = varchar("script_elaborato", 50)

    override val primaryKey = PrimaryKey(id)
}

class LogScriptDAO(id: EntityID<Int>) : IntEntity(id) {
    companion object : IntEntityClass<LogScriptDAO>(LogScriptTable)

    var ts_ricezione by LogScriptTable.ts_ricezione
    var script_ricevuto by LogScriptTable.script_ricevuto
    var script_elaborato by LogScriptTable.script_elaborato
}

suspend fun <T> suspendTransaction(block: Transaction.() -> T): T =
    newSuspendedTransaction(Dispatchers.IO, statement = block)

fun logScriptDaoToModel(dao: LogScriptDAO) = LogScript(
    dao.id.value,
    LocalDateTime.parse(dao.ts_ricezione.toString()),
    dao.script_ricevuto,
    dao.script_elaborato
)