package eu.maiora.routes

import io.ktor.server.application.*
import io.ktor.client.*
import io.ktor.client.engine.cio.*
import io.ktor.client.request.*
import io.ktor.client.statement.*
import io.ktor.http.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*
import kotlinx.serialization.Serializable
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json


fun Route.analizzaURLRoute() {
    post("/analizzaURL") {
        // Riceve il body della richiesta e lo deserializza in UrlRequest
        val urlRequest = try {
            call.receive<UrlRequest>()
        } catch (e: Exception) {
            return@post call.respondText("URL mancante " + e.stackTraceToString(), status = HttpStatusCode.BadRequest)
        }

        // Configura il JSON per la serializzazione
        val json = Json { prettyPrint = true }

        // Converte l'oggetto UrlRequest in una stringa JSON
        val jsonString = json.encodeToString(urlRequest)

        val client = HttpClient(CIO)
        try {
            val response: HttpResponse = client.post("https://hyo0tcstdh.execute-api.eu-west-1.amazonaws.com/dev/ai") {
                header(HttpHeaders.ContentType, ContentType.Application.Json)
                setBody(jsonString)
            }
            call.respond(response.status, response.bodyAsText())
        } catch (e: Exception) {
            call.respondText("Errore: ${e.message}", status = HttpStatusCode.InternalServerError)
        } finally {
            client.close()
        }
    }
}

@Serializable
data class UrlRequest(val body: String)
