package eu.maiora.routes

import eu.maiora.model.LogScript
import eu.maiora.model.LogScriptRepositoryImpl
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*


fun Route.logScriptRouting(repository : LogScriptRepositoryImpl) {
    route("/logScript"){
        get{
            val logScript = repository.allLogScript()
            call.respond(logScript)
        }

        get("{id}"){
            // Ottieni l'ID dal percorso
            val id = call.parameters["id"]?.toIntOrNull()

            if (id == null) {
                call.respondText("Invalid ID", status = HttpStatusCode.BadRequest)
                return@get
            }

            // Cerca il log_script per ID
            val logScript = repository.logScriptById(id)

            if (logScript != null) {
                call.respond(logScript)
            } else {
                call.respondText("Log Script Not Found", status = HttpStatusCode.NotFound)
            }
        }

        // Endpoint per aggiornare un log_script esistente tramite ID
        put("{id}") {
            // Ottieni l'ID dal percorso
            val id = call.parameters["id"]?.toIntOrNull()

            if (id == null) {
                call.respondText("Invalid ID", status = HttpStatusCode.BadRequest)
                return@put
            }

            // Parsing del body della richiesta
            val updateRequest = call.receive<LogScript>()

            // Aggiorna il record
            val updated = repository.editLogScript(updateRequest)

            if (updated) {
                call.respondText("Log Script Updated Successfully", status = HttpStatusCode.OK)
            } else {
                call.respondText("Log Script Not Found", status = HttpStatusCode.NotFound)
            }
        }


    }


}

